@@ -71,9 +71,15 @@ __all__ = [
     "FileLock"
 ]
 
-__version__ = "2.0.11"
+__version__ = "3.0.4"
 
-logger = logging.getLogger(__name__)
+
+_logger = None
+def logger():
+    """Returns the logger instance used in this module."""
+    global _logger
+    _logger = _logger or logging.getLogger(__name__)
+    return _logger
 
 
 # Exceptions
@@ -199,7 +205,7 @@ class BaseFileLock(object):
             with lock.acquire():
                 pass
 
-            # Or you use an equal try-finally construct:
+            # Or use an equivalent try-finally construct:
             lock.acquire()
             try:
                 pass
@@ -241,17 +247,17 @@ class BaseFileLock(object):
 
                 with self._thread_lock:
                     if not self.is_locked:
-                        logger.debug('Attempting to acquire lock %s on %s', lock_id, lock_filename)
+                        logger().debug('Attempting to acquire lock %s on %s', lock_id, lock_filename)
                         self._acquire()
 
                 if self.is_locked:
-                    logger.info('Lock %s acquired on %s', lock_id, lock_filename)
+                    logger().info('Lock %s acquired on %s', lock_id, lock_filename)
                     break
                 elif timeout >= 0 and time.time() - start_time > timeout:
-                    logger.debug('Timeout on aquiring lock %s on %s', lock_id, lock_filename)
+                    logger().debug('Timeout on acquiring lock %s on %s', lock_id, lock_filename)
                     raise Timeout(self._lock_file)
                 else:
-                    logger.debug(
+                    logger().debug(
                         'Lock %s not acquired on %s, waiting %s seconds ...',
                         lock_id, lock_filename, poll_intervall
                     )
@@ -305,10 +311,10 @@ class BaseFileLock(object):
                     lock_id = id(self)
                     lock_filename = self._lock_file
 
-                    logger.debug('Attempting to release lock %s on %s', lock_id, lock_filename)
+                    logger().debug('Attempting to release lock %s on %s', lock_id, lock_filename)
                     self._release()
                     self._lock_counter = 0
-                    logger.info('Lock %s released on %s', lock_id, lock_filename)
+                    logger().info('Lock %s released on %s', lock_id, lock_filename)
 
         return None
 
@@ -385,6 +391,10 @@ class UnixFileLock(BaseFileLock):
         return None
 
     def _release(self):
+        # Do not remove the lockfile:
+        #
+        #   https://github.com/benediktschmitt/py-filelock/issues/31
+        #   https://stackoverflow.com/questions/17708885/flock-removing-locked-file-without-race-condition
         fd = self._lock_file_fd
         self._lock_file_fd = None
         fcntl.flock(fd, fcntl.LOCK_UN)
